@@ -4,7 +4,7 @@
 @author: Ajay Arunachalam
 Created on: 25/10/2021
 Training the forecasting and Nowcasting model
-Version: 0.0.3
+Version: 0.0.5
 """
 
 
@@ -20,7 +20,6 @@ from .similarity import *
 from .gnn_layer import *
 from .stats import *
 
-
 class Forecast:
 
 	ts = globals()
@@ -49,8 +48,8 @@ class Forecast:
 
 		return ts, fc
 
-		assert ts == ts
-		assert fc == fc
+	assert ts == ts
+	assert fc == fc
 
 	def set_model_config(**kwargs):
 
@@ -64,10 +63,10 @@ class Forecast:
 
 		return select_model, select_user_path, select_scaler, forecast_window
 
-		assert select_model == select_model
-		assert select_user_path == select_user_path
-		assert select_scaler == select_scaler
-		assert forecast_window ==  forecast_window
+	assert select_model == select_model
+	assert select_user_path == select_user_path
+	assert select_scaler == select_scaler
+	assert forecast_window ==  forecast_window
 
 	def hyperparameter_config(**kwargs):
 
@@ -84,16 +83,19 @@ class Forecast:
 
 		return hidden_dim, layer_dim, batch_size, dropout, n_epochs, learning_rate, weight_decay
 
-		assert hidden_dim == hidden_dim
-		assert layer_dim == layer_dim
-		assert batch_size == batch_size
-		assert dropout == dropout
-		assert n_epochs == n_epochs
-		assert learning_rate == learning_rate
-		assert weight_decay == weight_decay
+	assert hidden_dim == hidden_dim
+	assert layer_dim == layer_dim
+	assert batch_size == batch_size
+	assert dropout == dropout
+	assert n_epochs == n_epochs
+	assert learning_rate == learning_rate
+	assert weight_decay == weight_decay
 
 	def forecast(df, ts, fc, opt, scaler, period:int, fq:str, select_scaler=select_scaler, ):
 
+		digit = ''.join(filter(str.isdigit, str(fq)))
+		interval = int(digit)
+
 		ff_df = Helper.make_future_df(df, ts, period, fq)
 
 		print(f'Forecast period dataframe: {ff_df.index}')
@@ -102,7 +104,13 @@ class Forecast:
 
 		#cols=['hour','month','day','day_of_week','week_of_year']
 
-		if str(fq)=='h' or str(fq)=='H':
+		frequency = ''.join([i for i in fq if not i.isdigit()])
+
+		#if any(str(frequency).startswith(tuple(l)) for l in ['h', 'H', 's', 'S', 'min', 'MIN', 'n', 'N']) and interval is not None:
+		if frequency in ['h', 'H', 's', 'S', 'min', 'MIN', 'n', 'N'] and interval is not None:
+
+
+		#if str(fq)=='h' or str(fq)=='H' or str(fq) == 's' or str(fq) == 'S' or str(fq) == 'min' or str(fq) == 'MIN' or str(fq) == 'n' or str(fq) == 'N' or interval is not None:  # hourly(h:m:s)
 
 			ff_full_features = Features.generate_date_time_features_hour(ff_df, ['hour','month','day','day_of_week','week_of_year'])
 			ff_full_features = Features.generate_cyclic_features(ff_full_features, 'hour', 24, 0)
@@ -112,7 +120,11 @@ class Forecast:
 
 			ff_full_features = Features.generate_other_related_features(df=ff_full_features)
 
-		elif str(fq)=='m' or str(fq)=='M':
+		elif frequency in ['d', 'D', 'w', 'W', 'm', 'M', 'q', 'Q', 'QS', '2q', '2Q', 'HA', 'Y', 'y', 'A'] and interval is not None:
+
+		#elif any(str(frequency).startswith(tuple(l)) for l in ['d', 'D', 'w', 'W', 'm', 'M', 'q', 'Q', 'QS', '2q', '2Q', 'HA', 'Y', 'y', 'A']) and interval is not None:
+
+		#elif str(fq) == 'd' or str(fq) == 'D' or str(fq) == 'w' or str(fq) == 'W' or str(fq)=='m' or str(fq)=='M' or str(fq) == 'q' or str(fq) == 'Q' or str(fq) == 'QS' or str(fq) == '2q' or str(fq) == '2Q' or str(fq) == 'HA' or str(fq) == 'y' or str(fq) == 'Y' or str(fq) == 'A' or interval is not None: # Yearly(Daily, weekly, monthly, quater, semi-annual, annual)
 
 			ff_full_features = Features.generate_date_time_features_month(ff_df, ['month','day_of_week','week_of_year'])
 			ff_full_features = Features.generate_cyclic_features(ff_full_features, 'day_of_week', 7, 0)
